==> libopenshot-0.3.2-x86_64-2ponce.txz: usr/doc/libopenshot-0.3.2/API/search/all_17.js <==
var searchData=
[
  ['uint64_0',['uint64',['../Clip_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;Clip.h'],['../ClipProcessingJobs_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;ClipProcessingJobs.h'],['../CVObjectDetection_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;CVObjectDetection.h'],['../CVStabilization_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;CVStabilization.h'],['../CVTracker_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;CVTracker.h'],['../Frame_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;Frame.h'],['../OpenCVUtilities_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;OpenCVUtilities.h']]],
  ['uint64_5fc_1',['UINT64_C',['../FFmpegUtilities_8h.html#a26a7bac63d90ef61175acb9f6fc4f2ca',1,'FFmpegUtilities.h']]],
  ['unittest_20libunittest_2',['UnitTest libunittest',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-LINUX.html#autotoc_md27',1,'UnitTest++ (libunittest++)'],['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-MAC.html#autotoc_md55',1,'UnitTest++ (libunittest++)'],['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md83',1,'UnitTest++ (libunittest++)']]],
  ['unmatcheddetections_3',['unmatchedDetections',['../classSortTracker.html#a3689c10b033fd73a68879ff95cc429cc',1,'SortTracker']]],
  ['unmatchedtrajectories_4',['unmatchedTrajectories',['../classSortTracker.html#ada9aef3b5f881fb36f904b9c29d6f819',1,'SortTracker']]],
  ['update_5',['update',['../classKalmanTracker.html#ac467937279efc8989bc312749203dc63',1,'KalmanTracker::update()'],['../classSortTracker.html#a90ba4cd6ebed03b703810edd0a24a125',1,'SortTracker::update()']]],
  ['updatecoefficients_6',['updateCoefficients',['../classopenshot_1_1Distortion_1_1Filter.html#a83831113dfdc68ea0bfffe5837365a67',1,'openshot::Distortion::Filter::updateCoefficients()'],['../classopenshot_1_1ParametricEQ_1_1Filter.html#a4c9597fecd4da25e415b513034be90fd',1,'openshot::ParametricEQ::Filter::updateCoefficients()']]],
  ['updatefftsize_7',['updateFftSize',['../classopenshot_1_1STFT.html#ac13d7abd52360cb6d141b43383f07011',1,'openshot::STFT']]],
  ['updatefilters_8',['updateFilters',['../classopenshot_1_1Distortion.html#a79c4077016e63bbf9da3fe6e1473cff2',1,'openshot::Distortion::updateFilters()'],['../classopenshot_1_1ParametricEQ.html#aa84b2b80e7ce8dcefb04e582a3b75aed',1,'openshot::ParametricEQ::updateFilters()']]],
  ['updatehopsize_9',['updateHopSize',['../classopenshot_1_1STFT.html#a72432acdc68df428809a21fdb33dcd4e',1,'openshot::STFT']]],
  ['updateparameters_10',['updateParameters',['../classopenshot_1_1STFT.html#a565d9d4d5ea7d7f0d3b9af425b37b58d',1,'openshot::STFT']]],
  ['updatepoint_11',['UpdatePoint',['../classopenshot_1_1Keyframe.html#abb9e530acdfe2ab6e144fccbcfe73221',1,'openshot::Keyframe']]],
  ['updatewindow_12',['updateWindow',['../classopenshot_1_1STFT.html#a456c20efb1b5829347900f03c8132db2',1,'openshot::STFT']]],
  ['us_20improve_20hardware_20support_13',['Help Us Improve Hardware Support',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2HW-ACCEL.html#autotoc_md13',1,'']]],
  ['use_5fhw_5faccel_14',['USE_HW_ACCEL',['../FFmpegUtilities_8h.html#afa0620a3c833f57b32a8a6ff8d7587d0',1,'FFmpegUtilities.h']]],
  ['use_5fsw_15',['USE_SW',['../FFmpegUtilities_8h.html#a7a2dd0fad5eb57db98a35270a5b6a38f',1,'FFmpegUtilities.h']]]
];

==> libopenshot-0.3.3-x86_64-1ponce.txz: usr/doc/libopenshot-0.3.3/API/search/all_17.js <==
var searchData=
[
  ['uint64_0',['uint64',['../Clip_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;Clip.h'],['../ClipProcessingJobs_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;ClipProcessingJobs.h'],['../CVObjectDetection_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;CVObjectDetection.h'],['../CVStabilization_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;CVStabilization.h'],['../CVTracker_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;CVTracker.h'],['../Frame_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;Frame.h'],['../OpenCVUtilities_8h.html#a675b708aad17b5e4de65233fe5ed3839',1,'uint64:&#160;OpenCVUtilities.h']]],
  ['uint64_5fc_1',['UINT64_C',['../FFmpegUtilities_8h.html#a26a7bac63d90ef61175acb9f6fc4f2ca',1,'FFmpegUtilities.h']]],
  ['unittest_20libunittest_2',['UnitTest libunittest',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-LINUX.html#autotoc_md27',1,'UnitTest++ (libunittest++)'],['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-MAC.html#autotoc_md55',1,'UnitTest++ (libunittest++)'],['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md83',1,'UnitTest++ (libunittest++)']]],
  ['unmatcheddetections_3',['unmatchedDetections',['../classSortTracker.html#a3689c10b033fd73a68879ff95cc429cc',1,'SortTracker']]],
  ['unmatchedtrajectories_4',['unmatchedTrajectories',['../classSortTracker.html#ada9aef3b5f881fb36f904b9c29d6f819',1,'SortTracker']]],
  ['update_5',['update',['../classKalmanTracker.html#ac467937279efc8989bc312749203dc63',1,'KalmanTracker::update()'],['../classSortTracker.html#a90ba4cd6ebed03b703810edd0a24a125',1,'SortTracker::update()']]],
  ['updatecoefficients_6',['updateCoefficients',['../classopenshot_1_1Distortion_1_1Filter.html#a83831113dfdc68ea0bfffe5837365a67',1,'openshot::Distortion::Filter::updateCoefficients()'],['../classopenshot_1_1ParametricEQ_1_1Filter.html#a4c9597fecd4da25e415b513034be90fd',1,'openshot::ParametricEQ::Filter::updateCoefficients()']]],
  ['updatefftsize_7',['updateFftSize',['../classopenshot_1_1STFT.html#ac13d7abd52360cb6d141b43383f07011',1,'openshot::STFT']]],
  ['updatefilters_8',['updateFilters',['../classopenshot_1_1Distortion.html#a79c4077016e63bbf9da3fe6e1473cff2',1,'openshot::Distortion::updateFilters()'],['../classopenshot_1_1ParametricEQ.html#aa84b2b80e7ce8dcefb04e582a3b75aed',1,'openshot::ParametricEQ::updateFilters()']]],
  ['updatehopsize_9',['updateHopSize',['../classopenshot_1_1STFT.html#a72432acdc68df428809a21fdb33dcd4e',1,'openshot::STFT']]],
  ['updateparameters_10',['updateParameters',['../classopenshot_1_1STFT.html#a565d9d4d5ea7d7f0d3b9af425b37b58d',1,'openshot::STFT']]],
  ['updatepoint_11',['UpdatePoint',['../classopenshot_1_1Keyframe.html#abb9e530acdfe2ab6e144fccbcfe73221',1,'openshot::Keyframe']]],
  ['updatewindow_12',['updateWindow',['../classopenshot_1_1STFT.html#a456c20efb1b5829347900f03c8132db2',1,'openshot::STFT']]],
  ['us_20improve_20hardware_20support_13',['Help Us Improve Hardware Support',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2HW-ACCEL.html#autotoc_md13',1,'']]],
  ['use_5fhw_5faccel_14',['USE_HW_ACCEL',['../FFmpegUtilities_8h.html#afa0620a3c833f57b32a8a6ff8d7587d0',1,'FFmpegUtilities.h']]],
  ['use_5fsw_15',['USE_SW',['../FFmpegUtilities_8h.html#a7a2dd0fad5eb57db98a35270a5b6a38f',1,'FFmpegUtilities.h']]]
];
